import type { WithElement } from './types';
/**
 * Base class for {@link PageObject} that contains stub implementations of a
 * subset of array methods (the ones that produce a possibly useful value). The
 * actual functionality is handled by the proxy, the implementations aren't
 * important, these are just here for type checking.
 *
 * It really seems like there should be a better way to do this, but I can't
 * figure out how else to make PageObject subclasses look like arrays of
 * `WithElement<this>`.
 *
 * @private
 */
export default class ArrayStub {
    /**
     * @private
     */
    readonly length: number;
    /**
     * @private
     */
    pop: () => WithElement<this> | undefined;
    /**
     * @private
     */
    concat: (...items: ConcatArray<WithElement<this>>[] | (WithElement<this> | ConcatArray<WithElement<this>>)[] | (WithElement<this> | ConcatArray<WithElement<this>>)[]) => WithElement<this>[];
    /**
     * @private
     */
    reverse: () => WithElement<this>[];
    /**
     * @private
     */
    shift: () => WithElement<this> | undefined;
    /**
     * @private
     */
    slice: (_start?: number, _end?: number) => WithElement<this>[];
    /**
     * @private
     */
    sort: (_compareFn?: (a: WithElement<this>, b: WithElement<this>) => number) => this[];
    /**
     * @private
     */
    indexOf: (_searchElement: WithElement<this>, _fromIndex?: number) => number;
    /**
     * @private
     */
    lastIndexOf: (_searchElement: WithElement<this>, _fromIndex?: number) => number;
    /**
     * @private
     */
    every: (predicate: (value: WithElement<this>, index: number, array: WithElement<this>[]) => unknown, _thisArg?: any) => boolean;
    /**
     * @private
     */
    some: (_predicate: (value: WithElement<this>, index: number, array: WithElement<this>[]) => unknown, _thisArg?: any) => boolean;
    /**
     * @private
     */
    forEach: (_callbackfn: (value: WithElement<this>, index: number, array: WithElement<this>[]) => void, _thisArg?: any) => void;
    /**
     * @private
     */
    map: <U>(_callbackfn: (value: WithElement<this>, index: number, array: WithElement<this>[]) => U, _thisArg?: any) => U[];
    /**
     * @private
     */
    filter: (predicate: (value: WithElement<this>, index: number, array: WithElement<this>[]) => unknown, thisArg?: any) => WithElement<this>[];
    /**
     * @private
     */
    reduce: <U>(_callbackfn: (previousValue: U, currentValue: WithElement<this>, currentIndex: number, array: WithElement<this>[]) => U, initialValue: U) => U;
    /**
     * @private
     */
    reduceRight: <U>(_callbackfn: (previousValue: U, currentValue: WithElement<this>, currentIndex: number, array: WithElement<this>[]) => U, initialValue: U) => U;
    /**
     * @private
     */
    find: (predicate: (value: WithElement<this>, index: number, obj: WithElement<this>[]) => unknown, thisArg?: any) => WithElement<this> | undefined;
    /**
     * @private
     */
    findIndex: (_predicate: (value: WithElement<this>, index: number, obj: WithElement<this>[]) => unknown, _thisArg?: any) => number;
    /**
     * @private
     */
    includes: (_searchElement: WithElement<this>, _fromIndex?: number) => boolean;
    /**
     * @private
     */
    [Symbol.iterator]: () => IterableIterator<WithElement<this>>;
    /**
     * @private
     */
    entries: () => IterableIterator<[number, WithElement<this>]>;
    /**
     * @private
     */
    keys: () => IterableIterator<number>;
    /**
     * @private
     */
    values: () => IterableIterator<WithElement<this>>;
    /**
     * @private
     */
    readonly [n: number]: this;
}
